@@ -14,6 +14,7 @@ from .utils import ExponentialSleep, IntervalTracker
 from .const import FETCH_BUFFER_SIZE_BYTES, MAX_FETCH_BUFFER_SIZE_BYTES, GET_MESSAGE_TIMEOUT
 from .offset import SimpleOffsetTracker, WindowedOffsetTracker
 from .message import SourceMessage
+from .kafka_utils import get_kafka_offset_range
 
 class TaskCode(object):
     def __init__(self, name, code):
@@ -110,16 +111,9 @@ class Task(object):
                                       max_buffer_size=MAX_FETCH_BUFFER_SIZE_BYTES)
 
             partition_ids = self.kafka.get_partition_ids_for_topic(topic)
-
-            # fetch offset range for each partition
-            reqs = [kafka.common.OffsetRequest(topic, partition_id, -1, 10000) for partition_id in partition_ids]
-            resps = self.kafka.send_offset_request(reqs) 
-            for resp in resps:
-                kafka.common.check_error(resp)
-                partition_id = resp.partition
+            server_offsets = get_kafka_offset_range(self.kafka, [(topic, partition_id) for partition_id in partition_ids])
+            for topic, partition_id, server_min, server_max in server_offsets:
                 our_offset = self.offsets.get(topic, partition_id)
-                server_max = resp.offsets[0]
-                server_min = resp.offsets[-1]
                 if our_offset > server_max:
                     raise RuntimeError('Stored offset for topic {0} and partition {1} ({2}) is larger '
                         'than maximal offset on server ({3}). This could be caused by state not synchronized '
